@@ -14,7 +14,7 @@ class TTRClient(object):
     represented by Python objects.  You can also update modify articles and
     feeds on the server.
     """
-    def __init__(self, url, user=None, password=None, auto_login=False):
+    def __init__(self, url, user=None, password=None, auto_login=False, http_auth=()):
         """
         Instantiate a new client.
 
@@ -30,11 +30,12 @@ class TTRClient(object):
         self.url = url + '/api/'
         self.user = user
         self.password = password
+        self.http_auth = http_auth
 
         self._session = requests.Session()
 
         if auto_login:
-            auth = TTRAuth(user, password)
+            auth = TTRAuth(user, password, http_auth)
             self._session.auth = auth
 
     def login(self):
@@ -72,7 +73,7 @@ class TTRClient(object):
         else:
             data = {'sid': self.sid}
         data.update(post_data)
-        r = self._session.post(self.url, data=json.dumps(data))
+        r = self._session.post(self.url, auth=self.http_auth, data=json.dumps(data))
         raise_on_error(r)
         return json.loads(r.text)
 
@@ -85,7 +86,7 @@ class TTRClient(object):
         """Get total number of subscribed feeds."""
         r = self._get_json({'op': 'getCounters'})
         for c in r['content']:
-            if c['id'] == u'subscribed-feeds':
+            if c['id'] == 'subscribed-feeds':
                 return int(c['counter'])
         return None
 
@@ -144,6 +145,19 @@ class TTRClient(object):
         })
         return [Feed(feed, self) for feed in r['content']]
 
+    def get_feed_tree(self, include_empty=False):
+        """
+        Get entire feed tree as decoded json data.
+
+        :param include_empty: *Optional* Include empty categories. Default is
+            ``False``.
+        """
+        r = self._get_json({
+            'op': 'getFeedTree',
+            'include_empty': include_empty,
+        })
+        return r['content']
+
     def get_labels(self):
         """Get a list of configured labels"""
         r = self._get_json({'op': 'getLabels'})
@@ -247,6 +261,22 @@ class TTRClient(object):
             'content': content
         })
 
+    def assign_label(self, article_id, label_id):
+        """
+        Assign an existing label to an article.
+
+        :param article_id: Article ID.
+        :param label_id: Label ID.
+        """
+        if isinstance(article_id, list):
+            article_id = ",".join([str(i) for i in article_id])
+        r = self._get_json({
+            'op': 'setArticleLabel',
+            'article_ids': article_id,
+            'label_id': label_id,
+            'assign': 'true',
+        })
+
     def mark_unread(self, article_id):
         """
         Mark an article as unread.
@@ -319,6 +349,17 @@ class TTRClient(object):
         r = self._get_json({'op': 'getConfig'})
         return r['content']['daemon_is_running']
 
+    def update_feed(self, feed_id):
+        """
+		Update specified feed
+		:param feed_id: id of the feed to update.
+ 
+		"""
+        r = self._get_json({
+			'op': 'updateFeed',
+            'feed_id': feed_id
+		})
+
     def subscribe(self, feed_url, category_id=0, login=None, password=None):
         """Subscribe to specified feed.
 
